@@ -29,6 +29,7 @@ __license__   = "LGPL"
 import pyatspi
 import time
 
+import orca.debug as debug
 import orca.orca as orca
 import orca.scripts.toolkits.clutter as clutter
 
@@ -49,6 +50,12 @@ class Script(clutter.Script):
     def getUtilities(self):
         return Utilities(self)
 
+    def deactivate(self):
+        """Called when this script is deactivated."""
+
+        self.utilities.clearCachedObjects()
+        super().deactivate()
+
     def skipObjectEvent(self, event):
         """Determines whether or not this event should be skipped due to
         being redundant, part of an event flood, etc."""
@@ -62,8 +69,21 @@ class Script(clutter.Script):
             if role == pyatspi.ROLE_DIALOG:
                 return False
 
+            if role == pyatspi.ROLE_WINDOW:
+                return self.utilities.isBogusWindowFocusClaim(event)
+
         return clutter.Script.skipObjectEvent(self, event)
 
+    def locusOfFocusChanged(self, event, oldFocus, newFocus):
+        if (event and event.type == "window:activate" and newFocus and not newFocus.name):
+            queuedEvent = self._getQueuedEvent("object:state-changed:focused", True)
+            if queuedEvent and queuedEvent.source != event.source:
+                msg = "GNOME SHELL: Have matching focused event. Not announcing nameless window."
+                debug.println(debug.LEVEL_INFO, msg, True)
+                return
+
+        super().locusOfFocusChanged(event, oldFocus, newFocus)
+
     def _presentDialogLabel(self, event):
         try:
             role = event.source.getRole()
@@ -227,4 +247,7 @@ class Script(clutter.Script):
         if event.type.startswith('object:state-changed:selected') and event.detail1:
             return True
 
+        if self.utilities.isBogusWindowFocusClaim(event):
+            return False
+
         return super().isActivatableEvent(event)
